You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by gi...@apache.org on 2026/04/21 05:11:35 UTC
(beam) branch nightly-refs/heads/master updated (0f48ffcbb27 -> 25370f50b39)
This is an automated email from the ASF dual-hosted git repository.
github-actions[bot] pushed a change to branch nightly-refs/heads/master
in repository https://gitbox.apache.org/repos/asf/beam.git
from 0f48ffcbb27 Bump nltk from 3.9.3 to 3.9.4 in /sdks/python/container/ml/py312 (#38227)
add ac161e8d229 Pin numbus-jose-jwt to 9.37.4 (#38187)
add 00e825e71ea Update hbase version to fix netty CVEs. (#38241)
add ce20f7345b5 Remove widget state data in run_inference_gemma.ipynb (#38248)
add 79fb3600f97 [Python] Expand SDF by default in PortableRunner (#37965)
add 2ee8b6b667d Improve Javadoc for Coder class and clarify Context usage (#38235)
add cacf8f43fc9 Bump lodash from 4.17.23 to 4.18.1 in /sdks/typescript (#38043)
add bc6dffee9d3 Bump flatted from 3.4.1 to 3.4.2 in /sdks/typescript (#37906)
add e696acdfad0 Bump github.com/aws/aws-sdk-go-v2/aws/protocol/eventstream in /sdks (#38101)
add 25370f50b39 Bump github.com/nats-io/nats-server/v2 from 2.12.4 to 2.12.6 in /sdks (#37940)
No new revisions were added by this update.
Summary of changes:
...am_PostCommit_Python_ValidatesRunner_Flink.json | 3 +-
...am_PostCommit_Python_ValidatesRunner_Spark.json | 3 +-
.../trigger_files/beam_PostCommit_XVR_Flink.json | 3 +-
.../trigger_files/beam_PostCommit_XVR_Spark3.json | 4 +-
.../notebooks/beam-ml/run_inference_gemma.ipynb | 698 ---------------------
sdks/go.mod | 18 +-
sdks/go.sum | 36 +-
.../java/org/apache/beam/sdk/coders/Coder.java | 5 +
sdks/java/io/expansion-service/build.gradle | 3 +
sdks/java/io/hbase/build.gradle | 2 +-
.../org/apache/beam/sdk/io/hbase/HBaseIOTest.java | 2 +-
sdks/java/io/iceberg/hive/build.gradle | 2 +-
.../runners/portability/portable_runner.py | 2 +-
.../runners/portability/portable_runner_test.py | 98 +++
sdks/typescript/package-lock.json | 27 +-
15 files changed, 159 insertions(+), 747 deletions(-)